( cd usr/lib ; rm -rf libchromeXvMC.so )
( cd usr/lib ; ln -sf libchromeXvMC.so.1.0.0 libchromeXvMC.so )
( cd usr/lib ; rm -rf libchromeXvMCPro.so )
( cd usr/lib ; ln -sf libchromeXvMCPro.so.1.0.0 libchromeXvMCPro.so )
( cd usr/lib ; rm -rf libchromeXvMCPro.so.1 )
( cd usr/lib ; ln -sf libchromeXvMCPro.so.1.0.0 libchromeXvMCPro.so.1 )
( cd usr/lib ; rm -rf libchromeXvMC.so.1 )
( cd usr/lib ; ln -sf libchromeXvMC.so.1.0.0 libchromeXvMC.so.1 )
